# Proof API Client

This library provides a client for the [Proof DashCam](https://proof.co.il/) Cloud API.
It is based on code found on [Proof Web Application](https://api.2proof.co.il/).
Library was created to facilitate a [Home Assistant](https://www.home-assistant.io/) integration with Proof DashCam.

Client is using asynchronous HTTP and WebSocket communication with the cloud.